@@ -1,4 +1,9 @@
 from marketools.stock import *
-from marketools import wallet
+from marketools.wallet import Wallet
 from marketools.simulator import simulator
 from marketools.analysis import *
+
+
+__pdoc__ = {}
+__pdoc__['extra_print'] = False
+__pdoc__['wallet'] = False
